@@ -68,6 +68,7 @@ sub make {
              This[ ]message[ ]was[ ]created[ ]automatically[ ]by[ ]mail[ ]delivery[ ]software[.]
             |A[ ]message[ ]that[ ]you[ ]sent[ ]was[ ]rejected[ ]by[ ]the[ ]local[ ]scannning[ ]code
             |A[ ]message[ ]that[ ]you[ ]sent[ ]contained[ ]one[ ]or[ ]more[ ]recipient[ ]addresses[ ]
+            |A[ ]message[ ]that[ ]you[ ]sent[ ]could[ ]not[ ]be[ ]delivered[ ]to[ ]all[ ]of[ ]its[ ]recipients
             |Message[ ][^ ]+[ ](?:has[ ]been[ ]frozen|was[ ]frozen[ ]on[ ]arrival)
             |The[ ][^ ]+[ ]router[ ]encountered[ ]the[ ]following[ ]error[(]s[)]:
             )
@@ -434,8 +435,8 @@ sub make {
             #   Diagnostic-Code: smtp; 450 TEMPERROR: retry timeout exceeded
             # The value of "Status:" indicates permanent error but the value
             # of SMTP reply code in Diagnostic-Code: field is "TEMPERROR"!!!!
-            my $sv = Sisimai::SMTP::Status->find($e->{'diagnosis'}) || '';
-            my $rv = Sisimai::SMTP::Reply->find($e->{'diagnosis'})  || '';
+            my $sv = $e->{'status'}    || Sisimai::SMTP::Status->find($e->{'diagnosis'}) || '';
+            my $rv = $e->{'replycode'} || Sisimai::SMTP::Reply->find($e->{'diagnosis'})  || '';
             my $s1 = 0; # First character of Status as integer
             my $r1 = 0; # First character of SMTP reply code as integer
             my $v1 = 0;
@@ -523,7 +524,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2020 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2021 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
